@@ -1787,3 +1787,8 @@ fn issue_1825() {
         ",
     );
 }
+
+#[test]
+fn issue_1851_1() {
+    test("x ?? (x = 'abc');", "x ?? (x = 'abc');");
+}
